@@ -21,22 +21,20 @@
 #ifndef DICTIONARYCREATIONWIZARD_H
 #define DICTIONARYCREATIONWIZARD_H
 
-#include <QtCore/QList>
-#include <QtCore/QMap>
-#include <QScrollArea>
+#include <QList>
+#include <QMap>
 #include <QWizard>
 
-#include <kcombobox.h>
-#include <knuminput.h>
-
 #include "ui_creationsourceui.h"
 #include "ui_creationsourcedetailsui.h"
 #include "ui_kdedocsourceui.h"
 
 class CompletionWizardWidget;
-class QTextCodec;
 class KComboBox;
 class MergeWidget;
+class QScrollArea;
+class QSpinBox;
+class QTextCodec;
 
 class CreationSourceWidget : public QWizardPage, public Ui::CreationSourceUI
 {
@@ -47,10 +45,10 @@ public:
     {
         setupUi(this);
         setObjectName(QLatin1String(name));
-        connect(emptyButton, SIGNAL(toggled(bool)), this, SLOT(emptyToggled(bool)));
+        connect(emptyButton, &QAbstractButton::toggled, this, &CreationSourceWidget::emptyToggled);
     }
 
-    virtual int nextId() const;
+    int nextId() const override;
 private slots:
     void emptyToggled(bool checked);
 };
@@ -65,7 +63,7 @@ public:
         setupUi(this);
         setObjectName(QLatin1String(name));
     }
-    virtual int nextId() const
+    int nextId() const override
     {
         return -1;
     }
@@ -83,9 +81,9 @@ public:
         languageButton->showLanguageCodes(true);
         languageButton->loadAllLanguages();
 
-        ooDictURL->setFilter(QLatin1String("*.dic"));
+        ooDictURL->setFilter(QStringLiteral("*.dic"));
     }
-    virtual int nextId() const
+    int nextId() const override
     {
         return -1;
     }
@@ -152,7 +150,7 @@ public:
 private:
     QScrollArea *scrollArea;
     QHash<QString, QCheckBox*> dictionaries;
-    QHash<QString, KIntNumInput*> weights;
+    QHash<QString, QSpinBox*> weights;
     QMap<QString, QString> languages;
 };
 
@@ -169,7 +167,7 @@ public:
     CompletionWizardWidget(QWidget *parent, const char *name);
     ~CompletionWizardWidget();
 
-    void ok(KConfig *config);
+    void ok();
 };
 
 #endif
